@@ -5,7 +5,9 @@
 
 from __future__ import division
 
-__version__ = "0.9.18"
+import importlib
+
+__version__ = "0.9.19"
 __author__ = "Samuel M. Smith"
 __license__ =  "MIT"
 
@@ -19,4 +21,5 @@ console.profuse("{0} version {1}\n".format(__path__[0], __version__))
 __all__ = ['base', 'trim']
 
 for m in __all__:
-    exec("from . import {0}".format(m))  #relative import
+    importlib.import_module(".{0}".format(m), package='ioflo')
+
