@@ -2,7 +2,9 @@
 
 """
 #print("module {0}".format(__name__))
-
+import sys
+if sys.version > '3':
+    xrange = range
 import copy
 from collections import deque
 
